@@ -12,6 +12,17 @@ typedef HV OHV;
 typedef AV OAV;
 typedef IO OIO;
 
+#ifndef hv_storehek
+#  define hv_storehek(hv, hek, val) \
+    hv_common((hv), NULL, HEK_KEY(hek), HEK_LEN(hek), HEK_UTF8(hek), HV_FETCH_ISSTORE|HV_FETCH_JUST_SV, (val), HEK_HASH(hek))
+#  define hv_fetchhek(hv, hek, lval) \
+    ((SV**)hv_common( \
+        (hv), NULL, HEK_KEY(hek), HEK_LEN(hek), HEK_UTF8(hek), (lval) ? (HV_FETCH_JUST_SV|HV_FETCH_LVALUE) : HV_FETCH_JUST_SV, NULL, HEK_HASH(hek) \
+    ))
+#  define hv_deletehek(hv, hek, flags) \
+    hv_common((hv), NULL, HEK_KEY(hek), HEK_LEN(hek), HEK_UTF8(hek), (flags)|HV_DELETE, NULL, HEK_HASH(hek))
+#endif
+
 namespace xs {
 
 enum next_t {
